@@ -240,6 +240,7 @@ class Call:
 
             # Process packet
             packet = {"item": manifest_item, "response": response}
+            logger.info(f'RESPONSE {packet["response"].status_code}: {packet["item"]["id"]}')
             self._post_call(packet)
 
             # Wait
@@ -259,16 +260,19 @@ class Call:
             response = session.get(manifest_item["url"])
             return {"item": manifest_item, "response": response}
 
-        with ThreadPoolExecutor(max_workers=THREAD_POOL) as executor:
-            for packet in list(executor.map(get, manifest)):
-                # Process packets
-                self._post_call(packet)
+        for x in range(0, len(manifest), self.batch_size):
+            logger.info(f'BATCH {manifest[x]["id"]}')
+
+            with ThreadPoolExecutor(max_workers=THREAD_POOL) as executor:
+                for packet in list(executor.map(get, manifest[x:x+self.batch_size])):
+                    # Process packets
+                    logger.debug(f'RESPONSE {packet["response"].status_code}: {packet["item"]["id"]}')
+                    self._post_call(packet)
 
     def _post_call(self, packet):
         """Processes and saves call data."""
 
         packet["response"].raise_for_status()
-        logger.debug(f'RESPONSE {packet["response"].status_code}: {packet["item"]["id"]}')
 
         if self.format == "json":
             response_json = packet["response"].json()
@@ -343,7 +347,7 @@ class Call:
                 self.data = packet["response"]
             dir = pathlib.Path(self.output)
             name = pathlib.Path(packet["item"]["id"]).with_suffix(self.extension)
-            self.file = dir / name
+            self.file = dir / str(name)
             save_method = "".join(["_save_", self.format])
             getattr(Call, save_method)(self)
 
@@ -444,6 +448,7 @@ class Call:
         self.skip = skip
         self.clear = clear
         self.threads = min(32, os.cpu_count() + 4)
+        self.batch_size = 100
         self.timestamp = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
         self.input = "dict"
         self.db_extensions = ".db"
